Attention is currently required from: lynxis lazus.
Hello Jenkins Builder,
I'd like you to reexamine a change. Please visit
https://gerrit.osmocom.org/c/osmo-asf4-dfu/+/42275?usp=email
to look at the new patch set (#2).
The following approvals got outdated and were removed:
Verified-1 by Jenkins Builder
Change subject: Replace snprintf() to free 4 kb
......................................................................
Replace snprintf() to free 4 kb
Change-Id: Ide644648bda86d4ae77a6713d1e140a4b78ba835
---
M usb_flash_main.c
1 file changed, 15 insertions(+), 2 deletions(-)
git pull ssh://gerrit.osmocom.org:29418/osmo-asf4-dfu refs/changes/75/42275/2
--
To view, visit https://gerrit.osmocom.org/c/osmo-asf4-dfu/+/42275?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: newpatchset
Gerrit-Project: osmo-asf4-dfu
Gerrit-Branch: master
Gerrit-Change-Id: Ide644648bda86d4ae77a6713d1e140a4b78ba835
Gerrit-Change-Number: 42275
Gerrit-PatchSet: 2
Gerrit-Owner: lynxis lazus <lynxis(a)fe80.eu>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Attention: lynxis lazus <lynxis(a)fe80.eu>
Attention is currently required from: laforge.
Hello Jenkins Builder, laforge,
I'd like you to reexamine a change. Please visit
https://gerrit.osmocom.org/c/osmo-asf4-dfu/+/42273?usp=email
to look at the new patch set (#2).
The following approvals got outdated and were removed:
Verified-1 by Jenkins Builder
Change subject: dfu-download: flash the first block in manifest phase
......................................................................
dfu-download: flash the first block in manifest phase
To prevent half flashed applications, erase the first page
when dfu downloading starts and save the first block for later.
In manifest stage, flash the first block.
If the first 4 byte are 0xffffffff, the board won't boot
into application and go into the dfu bootloader.
Change-Id: I894f3ee71587ccb287e92d7025039954991c631f
---
M usb/class/dfu/device/dfudf.c
M usb/class/dfu/device/dfudf.h
M usb_start.c
3 files changed, 51 insertions(+), 9 deletions(-)
git pull ssh://gerrit.osmocom.org:29418/osmo-asf4-dfu refs/changes/73/42273/2
--
To view, visit https://gerrit.osmocom.org/c/osmo-asf4-dfu/+/42273?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: newpatchset
Gerrit-Project: osmo-asf4-dfu
Gerrit-Branch: master
Gerrit-Change-Id: I894f3ee71587ccb287e92d7025039954991c631f
Gerrit-Change-Number: 42273
Gerrit-PatchSet: 2
Gerrit-Owner: lynxis lazus <lynxis(a)fe80.eu>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-Attention: laforge <laforge(a)osmocom.org>
Attention is currently required from: lynxis lazus, pespin.
laforge has posted comments on this change by lynxis lazus. ( https://gerrit.osmocom.org/c/osmo-asf4-dfu/+/42170?usp=email )
Change subject: dfu: mainloop: work on a local copy of dfu_state
......................................................................
Patch Set 4:
(2 comments)
Patchset:
PS4:
> AFAIU: Pau asked if this assignment itself is atomic (last_dfu_state = dfu_state) and if not would n […]
Acknowledged
File usb_start.c:
https://gerrit.osmocom.org/c/osmo-asf4-dfu/+/42170/comment/5c2bd1ac_9544150… :
PS2, Line 162: enum usb_dfu_state last_dfu_state = dfu_state;
> I have no clue on details where this is being executed, so no idea, hence why I'm asking :D
Acknowledged
--
To view, visit https://gerrit.osmocom.org/c/osmo-asf4-dfu/+/42170?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: osmo-asf4-dfu
Gerrit-Branch: master
Gerrit-Change-Id: Ic146c8fa5ba25425cf785bae66f9c99b0faab944
Gerrit-Change-Number: 42170
Gerrit-PatchSet: 4
Gerrit-Owner: lynxis lazus <lynxis(a)fe80.eu>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-CC: pespin <pespin(a)sysmocom.de>
Gerrit-Attention: pespin <pespin(a)sysmocom.de>
Gerrit-Attention: lynxis lazus <lynxis(a)fe80.eu>
Gerrit-Comment-Date: Thu, 05 Mar 2026 15:57:40 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: laforge <laforge(a)osmocom.org>
Comment-In-Reply-To: pespin <pespin(a)sysmocom.de>
Comment-In-Reply-To: lynxis lazus <lynxis(a)fe80.eu>
dexter has uploaded this change for review. ( https://gerrit.osmocom.org/c/pysim/+/42274?usp=email )
Change subject: esim/http_json_api: allow URL rewriting
......................................................................
esim/http_json_api: allow URL rewriting
The URL used when HTTP requests are performed is defined statically
with the url_prefix passed to the constructor of JsonHttpApiClient
together with the path property in JsonHttpApiFunction.
For applications that require dynamic URLs there is no way to rewrite
the URL. Let's add a mechanism that allows API users to apply custom
URL reqriting rules by adding a reqrite_url method to
JsonHttpApiFunction. API users may then overload this method with a
custom implementation as needed.
Related: SYS#7918
Change-Id: Id2713a867079cc140517fe312189e5e2162608a5
---
M pySim/esim/http_json_api.py
1 file changed, 32 insertions(+), 4 deletions(-)
git pull ssh://gerrit.osmocom.org:29418/pysim refs/changes/74/42274/1
diff --git a/pySim/esim/http_json_api.py b/pySim/esim/http_json_api.py
index cd95e0d..9804837 100644
--- a/pySim/esim/http_json_api.py
+++ b/pySim/esim/http_json_api.py
@@ -180,7 +180,7 @@
# receives from the a requesting client. The same applies vice versa to class variables that have an "output_"
# prefix.
# path of the API function (e.g. '/gsma/rsp2/es2plus/confirmOrder')
path = None
# dictionary of input parameters. key is parameter name, value is ApiParam class
@@ -336,6 +336,22 @@
output[p] = p_class.decode(v)
return output
+ def rewrite_url(self, data: dict, url: str) -> (dict, str):
+ """
+ Rewrite a static URL using information passed in the data dict. This method may be overloaded by a derived
+ class to allow fully dynamic URLs. The input parameters required for the URL rewriting may be passed using
+ data parameter. In case those parameters are additional parameters that are not intended to be passed to
+ the encode_client method later, they must be removed explcitly.
+
+ Args:
+ data: (see JsonHttpApiClient and JsonHttpApiServer)
+ url: statically generated URL string (see comment in JsonHttpApiClient)
+ """
+
+ # This implementation is a placeholder in which we do not perform any URL rewriting. We just pass through data
+ # and url unmodified.
+ return data, url
+
class JsonHttpApiClient():
def __init__(self, api_func: JsonHttpApiFunction, url_prefix: str, func_req_id: Optional[str],
session: requests.Session):
@@ -352,8 +368,21 @@
self.session = session
def call(self, data: dict, func_call_id: Optional[str] = None, timeout=10) -> Optional[dict]:
- """Make an API call to the HTTP API endpoint represented by this object. Input data is passed in `data` as
- json-serializable dict. Output data is returned as json-deserialized dict."""
+ """
+ Make an API call to the HTTP API endpoint represented by this object. Input data is passed in `data` as
+ json-serializable fields. `data` may also contain additional parameters required for URL reqriting (see
+ rewrite_url in class JsonHttpApiFunction). Output data is returned as json-deserialized dict.
+
+ Args:
+ data: Input data required to perform the request.
+ func_call_id: Function Call Identifier, if present a header field is generated automatically.
+ timeout: Maximum amount of time to wait for the request to complete.
+ """
+
+ # The URL used for the HTTP request (see below) normally consists of the initially given url_prefix
+ # concatenated with the path defined by the JsonHttpApiFunction definition. This static URL path may be
+ # rewritten by rewrite_url method defined in the JsonHttpApiFunction.
+ data, url = self.api_func.rewrite_url(data, self.url_prefix + self.api_func.path)
# In case a function caller ID is supplied, use it together with the stored function requestor ID to generate
# and prepend the header field according to SGP.22, section 6.5.1.1 and 6.5.1.3. (the presence of the header
@@ -373,7 +402,6 @@
req_headers.update(self.api_func.extra_http_req_headers)
# Perform HTTP request
- url = self.url_prefix + self.api_func.path
logger.debug("HTTP REQ %s - hdr: %s '%s'" % (url, req_headers, encoded))
response = self.session.request(self.api_func.http_method, url, data=encoded, headers=req_headers, timeout=timeout)
logger.debug("HTTP RSP-STS: [%u] hdr: %s" % (response.status_code, response.headers))
@@ -180,7 +180,7 @@
# receives from the a requesting client. The same applies vice versa to class variables that have an "output_"
# prefix.
- # path of the API function (e.g. '/gsma/rsp2/es2plus/confirmOrder')
+ # path of the API function (e.g. '/gsma/rsp2/es2plus/confirmOrder', see also method rewrite_url).
path = None
# dictionary of input parameters. key is parameter name, value is ApiParam class
--
To view, visit https://gerrit.osmocom.org/c/pysim/+/42274?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: newchange
Gerrit-Project: pysim
Gerrit-Branch: master
Gerrit-Change-Id: Id2713a867079cc140517fe312189e5e2162608a5
Gerrit-Change-Number: 42274
Gerrit-PatchSet: 1
Gerrit-Owner: dexter <pmaier(a)sysmocom.de>
Attention is currently required from: falconia, laforge, lynxis lazus.
csaba.sipos has posted comments on this change by csaba.sipos. ( https://gerrit.osmocom.org/c/osmo-bsc/+/42246?usp=email )
Change subject: nokia_site: Add new BTS types to the list
......................................................................
Patch Set 2:
(1 comment)
Patchset:
PS2:
Gerrit say it is my turn. Have no idea what else needs to be done on this, so I hit reply.
--
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/42246?usp=email
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ia0dbbf148394d8205dc9219b41cfba3cf62bdeaa
Gerrit-Change-Number: 42246
Gerrit-PatchSet: 2
Gerrit-Owner: csaba.sipos <metro4(a)freemail.hu>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: falconia <falcon(a)freecalypso.org>
Gerrit-Reviewer: laforge <laforge(a)osmocom.org>
Gerrit-Reviewer: lynxis lazus <lynxis(a)fe80.eu>
Gerrit-CC: domi <domi(a)tomcsanyi.net>
Gerrit-CC: pespin <pespin(a)sysmocom.de>
Gerrit-Attention: falconia <falcon(a)freecalypso.org>
Gerrit-Attention: laforge <laforge(a)osmocom.org>
Gerrit-Attention: lynxis lazus <lynxis(a)fe80.eu>
Gerrit-Comment-Date: Thu, 05 Mar 2026 13:43:54 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No